@@ -28,20 +28,22 @@ def parse_markdown(text: str) -> list[CodeSnippet]:
     Supports:
       - <!-- pytestmark: <mark> --> comments immediately before a code fence
       - <!-- codeblock-name: <name> --> comments for naming
+      - <!-- continue:  <name> --> comments for grouping with a named snippet
       - Fenced code blocks with ```python (and optional name=<name> in the
         info string)
 
-    Captures each snippet’s name, code, starting line, and any pytest marks.
+    Captures each snippet's name, code, starting line, and any pytest marks.
     """
-    snippets: list[CodeSnippet] = []
+    snippets:  list[CodeSnippet] = []
     lines = text.splitlines()
-    pending_name: Optional[str] = None
+    pending_name:  Optional[str] = None
+    pending_continue: Optional[str] = None
     pending_marks: list[str] = [CODEBLOCK_MARK]
     pending_fixtures: list[str] = []
     in_block = False
     fence = ""
     block_indent = 0
-    code_buffer: list[str] = []
+    code_buffer:  list[str] = []
     snippet_name: Optional[str] = None
     start_line = 0
 
@@ -63,6 +65,13 @@ def parse_markdown(text: str) -> list[CodeSnippet]:
                     pending_fixtures.append(m.group(1))
                 continue
 
+            # Check for continue comment
+            if stripped.startswith("<!--") and "continue:" in stripped:
+                m = re.match(r"<!--\s*continue:\s*(\S+)\s*-->", stripped)
+                if m:
+                    pending_continue = m.group(1)
+                continue
+
             # Check for name comment
             if stripped.startswith("<!--") and "codeblock-name:" in stripped:
                 m = re.match(
@@ -113,16 +122,23 @@ def parse_markdown(text: str) -> list[CodeSnippet]:
                 # end of block
                 in_block = False
                 code_text = "\n".join(code_buffer)
+                # continue overrides snippet_name for grouping
+                if pending_continue:
+                    final_name = pending_continue
+                    pending_continue = None
+                else:
+                    final_name = snippet_name
                 snippets.append(CodeSnippet(
-                    name=snippet_name,
+                    name=final_name,
                     code=code_text,
                     line=start_line,
                     marks=pending_marks.copy(),
                     fixtures=pending_fixtures.copy(),
                 ))
                 # reset pending marks after collecting
-                pending_marks.clear()
+                pending_marks = [CODEBLOCK_MARK]  # Reset to default
                 snippet_name = None
+                pending_fixtures.clear()  # Clear pending fixtures
             else:
                 # collect code lines (dedent by block_indent)
                 if line.strip() == "":
@@ -157,7 +173,7 @@ class MarkdownFile(pytest.File):
             _fpath = str(self.path)
 
             # Build list of fixture names requested by this snippet
-            _fixture_names: list[str] = list(sn.fixtures)
+            _fixture_names:  list[str] = list(sn.fixtures)
 
             # If snippet is marked as needing DB, also request the `db`
             # fixture, unless user already added it explicitly.
